@@ -1,6 +1,6 @@
 /*
  * Oaks
- * Copyright (c) 2012  Akira Terasaki
+ * Copyright (c) 2012-2014  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -40,7 +40,14 @@ public class GroupBy {
 		StringBuilder buf = new StringBuilder( "group by " );
 		for ( int i = 0; i < size; i++ ) {
 			if ( i > 0 )	buf = buf.append( "," );
-			buf = buf.append( Field.getName( fld.get( i ) ) );
+			String name = null;
+			try {
+				name = Field.getName( fld.get( i ) );
+			}
+			catch(DB.DBException e) {
+				name = e.getMessage();
+			}
+			buf = buf.append( name );
 		}
 		return buf.toString();
 	}
